==> haskell-summoner-2.0.1.1-554-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner
version:              2.0.1.1
visibility:           public
id:                   summoner-2.0.1.1-79W7FmUDFEmF8VdH8vFIRo
key:                  summoner-2.0.1.1-79W7FmUDFEmF8VdH8vFIRo
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             CLI, CLI Tool, Development
abi:                  75e758aa60e7354482a2f7d896888708
exposed:              True
exposed-modules:
    Summoner Summoner.CLI Summoner.Config Summoner.CustomPrelude
    Summoner.Decision Summoner.Default Summoner.GhcVer Summoner.License
    Summoner.Mode Summoner.Project Summoner.Question Summoner.Settings
    Summoner.Source Summoner.Template Summoner.Template.Cabal
    Summoner.Template.Doc Summoner.Template.GitHub
    Summoner.Template.Haskell Summoner.Template.Script
    Summoner.Template.Stack Summoner.Text Summoner.Tree

hidden-modules:       Paths_summoner
import-dirs:          /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner
hs-libraries:         HSsummoner-2.0.1.1-79W7FmUDFEmF8VdH8vFIRo
depends:
    base-4.17.2.1 relude-1.2.2.0-3eEWnvqgKx8IbK6JLYpeL
    aeson-2.1.2.1-4xKrNuS491zGhSp7DRfhkt
    colourista-0.1.0.2-4qDUT2aC8rs4XDJ4IX98fo containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    generic-data-1.1.0.0-3LriBWTJBxb8rfkjCGX2U2
    gitrev-1.3.1-H2G7FNkm0RTIvLJOJ6VmrQ
    neat-interpolation-0.5.1.4-E8FxT6vYkepLharyGBxSzj
    optparse-applicative-0.17.1.0-xKs1W8pAM5KVMPAPWPohl
    process-1.6.18.0 shellmet-0.0.5.0-8dHPbSaTBeZLemnAWme0mC text-2.0.2
    time-1.12.2 tomland-1.3.3.3-L512XEHJiOc2qqH0zDu3wU
    validation-selective-0.2.0.0-6qhRgrzPNgC7Ia1mNilh5D

haddock-interfaces:   /usr/share/doc/haskell-summoner/html/summoner.haddock
haddock-html:         /usr/share/doc/haskell-summoner/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-summoner-2.0.1.1-555-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner
version:              2.0.1.1
visibility:           public
id:                   summoner-2.0.1.1-FSsHnGf55dA5HYNN4PpQhH
key:                  summoner-2.0.1.1-FSsHnGf55dA5HYNN4PpQhH
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             CLI, CLI Tool, Development
abi:                  a641d5ea820a286aa2ec417e98523478
exposed:              True
exposed-modules:
    Summoner Summoner.CLI Summoner.Config Summoner.CustomPrelude
    Summoner.Decision Summoner.Default Summoner.GhcVer Summoner.License
    Summoner.Mode Summoner.Project Summoner.Question Summoner.Settings
    Summoner.Source Summoner.Template Summoner.Template.Cabal
    Summoner.Template.Doc Summoner.Template.GitHub
    Summoner.Template.Haskell Summoner.Template.Script
    Summoner.Template.Stack Summoner.Text Summoner.Tree

hidden-modules:       Paths_summoner
import-dirs:          /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner
hs-libraries:         HSsummoner-2.0.1.1-FSsHnGf55dA5HYNN4PpQhH
depends:
    base-4.17.2.1 relude-1.2.2.0-9vPXuNUxFl2AyzKVXyCwF1
    aeson-2.1.2.1-JUxXPniSz0YG5YB65a9rRK
    colourista-0.1.0.2-AgSQhe0fj1rD4Bgtl0xJFg containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    generic-data-1.1.0.0-Ji6H0IFQRYUCEGJ2k0TZpo
    gitrev-1.3.1-H2G7FNkm0RTIvLJOJ6VmrQ
    neat-interpolation-0.5.1.4-5ZF5Q9CXP6jDm8WTN6mBFL
    optparse-applicative-0.17.1.0-2Uxzw63jP0W13nA1A9AHJz
    process-1.6.18.0 shellmet-0.0.5.0-2YiGgrko93KECLBKvEmQfF text-2.0.2
    time-1.12.2 tomland-1.3.3.3-9t4tSnB8ocCCfZ74g0O9KH
    validation-selective-0.2.0.0-IPNTrPXtiw31IliZPvhL9e

haddock-interfaces:   /usr/share/doc/haskell-summoner/html/summoner.haddock
haddock-html:         /usr/share/doc/haskell-summoner/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
